#define GLFW_INCLUDE_NONE
#include <GLFW/glfw3.h>
#include "glad.h"

#include "Renderer.h"

#undef APIENTRY
#define WIN32_LEAN_AND_MEAN
#include <Windows.h>

static void errorCallback(int error, const char* desc)
{
    MessageBoxA(NULL, desc, "Error", MB_ICONERROR | MB_OK);
}

int main()
{
    glfwSetErrorCallback(errorCallback);

    if (!glfwInit()) {
        return 1;
    }

    glfwWindowHint(GLFW_CLIENT_API, GLFW_OPENGL_ES_API);
    glfwWindowHint(GLFW_CONTEXT_VERSION_MAJOR, 3);
    glfwWindowHint(GLFW_CONTEXT_VERSION_MINOR, 0);
    GLFWwindow* window = glfwCreateWindow(1024, 768, "Krimi Dinner", nullptr, nullptr);
    if (!window) {
        glfwTerminate();
        return 1;
    }
    glfwMakeContextCurrent(window);
    int ret = gladLoadGLES2Loader((GLADloadproc)glfwGetProcAddress);
    if (!ret) {
        MessageBoxA(nullptr, "Failed to load GLES3", "Error", MB_ICONERROR | MB_OK);
        glfwDestroyWindow(window);
        glfwTerminate();
        return 1;
    }

    Renderer::create();

    glfwSwapInterval(1);
    while (!glfwWindowShouldClose(window)) {
        glfwPollEvents();

        Renderer::ptr->addRect(100, 100, 500, 500, 0.3, 0.3, 0.3, 1.0f);

        int w, h;
        glfwGetFramebufferSize(window, &w, &h);
        Renderer::ptr->renderFrame(static_cast<float>(w), static_cast<float>(h));

        glfwSwapBuffers(window);
    }

    glfwDestroyWindow(window);
    glfwTerminate();
    return 0;
}